"""
`pyvale`: the python validation engine. Used to simulate experimental data from
an input multi-physics simulation by explicitly modelling sensors with realistic
uncertainties. Useful for experimental design, sensor placement optimisation,
testing simulation validation metrics and testing digital shadows/twins.
"""

"""
================================================================================
pyvale: the python validation engine
License: MIT
Copyright (C) 2025 The Computer Aided Validation Team
================================================================================
"""
# NOTE: this simplifies and decouples how the user calls pyvale from the
# underlying project structure: the user should be able to use 'pyvale.'
# and access everything in one layer without multiple import dots

from pyvale.core.dataset import *

from pyvale.core.field import *
from pyvale.core.fieldscalar import *
from pyvale.core.fieldvector import *
from pyvale.core.fieldtensor import *
from pyvale.core.fieldconverter import *
from pyvale.core.fieldtransform import *

from pyvale.core.integratorspatial import *
from pyvale.core.integratorquadrature import *
from pyvale.core.integratorrectangle import *
from pyvale.core.integratorfactory import *

from pyvale.core.sensordescriptor import *
from pyvale.core.sensortools import *
from pyvale.core.sensorarray import *
from pyvale.core.sensorarrayfactory import *
from pyvale.core.sensorarraypoint import *
from pyvale.core.sensordata import *

from pyvale.core.camera import *
from pyvale.core.cameradata import *
from pyvale.core.cameradata2d import *
from pyvale.core.cameratools import *

import pyvale.core.cython.rastercyth as rastercyth
from pyvale.core.rastercy import *

from pyvale.core.rendermesh import *
from pyvale.core.rasternp import *

from pyvale.core.imagedef2d import *

from pyvale.core.errorintegrator import *
from pyvale.core.errorrand import *
from pyvale.core.errorsysindep import *
from pyvale.core.errorsysdep import *
from pyvale.core.errorsysfield import *
from pyvale.core.errordriftcalc import *

from pyvale.core.generatorsrandom import *

from pyvale.core.visualopts import *
from pyvale.core.visualtools import *
from pyvale.core.visualsimplotter import *
from pyvale.core.visualsimanimator import *
from pyvale.core.visualexpplotter import *
from pyvale.core.visualtraceplotter import *
from pyvale.core.visualimages import *
from pyvale.core.visualimagedef import *

from pyvale.core.analyticmeshgen import *
from pyvale.core.analyticsimdatagenerator import *
from pyvale.core.analyticsimdatafactory import *

from pyvale.core.experimentsimulator import *
